# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SqlTableArgs', 'SqlTable']

@pulumi.input_type
class SqlTableArgs:
    def __init__(__self__, *,
                 catalog_name: pulumi.Input[_builtins.str],
                 schema_name: pulumi.Input[_builtins.str],
                 table_type: pulumi.Input[_builtins.str],
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_keys: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 columns: Optional[pulumi.Input[Sequence[pulumi.Input['SqlTableColumnArgs']]]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 data_source_format: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 partitions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 provider_config: Optional[pulumi.Input['SqlTableProviderConfigArgs']] = None,
                 storage_credential_name: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_location: Optional[pulumi.Input[_builtins.str]] = None,
                 view_definition: Optional[pulumi.Input[_builtins.str]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SqlTable resource.
        :param pulumi.Input[_builtins.str] catalog_name: Name of parent catalog. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] schema_name: Name of parent Schema relative to parent Catalog. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] table_type: Distinguishes a view vs. managed/external Table. `MANAGED`, `EXTERNAL` or `VIEW`. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] cluster_id: All table CRUD operations must be executed on a running cluster or SQL warehouse. If a cluster_id is specified, it will be used to execute SQL commands to manage this table. If empty, a cluster will be created automatically with the name `terraform-sql-table`. Conflicts with `warehouse_id`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] cluster_keys: a subset of columns to liquid cluster the table by. For automatic clustering, set `cluster_keys` to `["AUTO"]`. To turn off clustering, set it to `["NONE"]`. Conflicts with `partitions`.
        :param pulumi.Input[_builtins.str] comment: User-supplied free-form text. Changing the comment is not currently supported on the `VIEW` table type.
        :param pulumi.Input[_builtins.str] data_source_format: External tables are supported in multiple data source formats. The string constants identifying these formats are `DELTA`, `CSV`, `JSON`, `AVRO`, `PARQUET`, `ORC`, and `TEXT`. Change forces the creation of a new resource. Not supported for `MANAGED` tables or `VIEW`.
        :param pulumi.Input[_builtins.str] name: Name of table relative to parent catalog and schema. Change forces the creation of a new resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] options: Map of user defined table options. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] owner: User name/group name/sp application_id of the table owner.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] partitions: a subset of columns to partition the table by. Change forces the creation of a new resource. Conflicts with `cluster_keys`.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] properties: A map of table properties.
        :param pulumi.Input['SqlTableProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] storage_credential_name: For EXTERNAL Tables only: the name of storage credential to use. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] storage_location: URL of storage location for Table data (required for EXTERNAL Tables).  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.).  Not supported for `VIEW` or `MANAGED` table_type.
        :param pulumi.Input[_builtins.str] view_definition: SQL text defining the view (for `table_type == "VIEW"`). Not supported for `MANAGED` or `EXTERNAL` table_type.
        :param pulumi.Input[_builtins.str] warehouse_id: All table CRUD operations must be executed on a running cluster or SQL warehouse. If a `warehouse_id` is specified, that SQL warehouse will be used to execute SQL commands to manage this table. Conflicts with `cluster_id`.
        """
        pulumi.set(__self__, "catalog_name", catalog_name)
        pulumi.set(__self__, "schema_name", schema_name)
        pulumi.set(__self__, "table_type", table_type)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if cluster_keys is not None:
            pulumi.set(__self__, "cluster_keys", cluster_keys)
        if columns is not None:
            pulumi.set(__self__, "columns", columns)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if data_source_format is not None:
            pulumi.set(__self__, "data_source_format", data_source_format)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if partitions is not None:
            pulumi.set(__self__, "partitions", partitions)
        if properties is not None:
            pulumi.set(__self__, "properties", properties)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if storage_credential_name is not None:
            pulumi.set(__self__, "storage_credential_name", storage_credential_name)
        if storage_location is not None:
            pulumi.set(__self__, "storage_location", storage_location)
        if view_definition is not None:
            pulumi.set(__self__, "view_definition", view_definition)
        if warehouse_id is not None:
            pulumi.set(__self__, "warehouse_id", warehouse_id)

    @_builtins.property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of parent catalog. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "catalog_name")

    @catalog_name.setter
    def catalog_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "catalog_name", value)

    @_builtins.property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of parent Schema relative to parent Catalog. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "schema_name", value)

    @_builtins.property
    @pulumi.getter(name="tableType")
    def table_type(self) -> pulumi.Input[_builtins.str]:
        """
        Distinguishes a view vs. managed/external Table. `MANAGED`, `EXTERNAL` or `VIEW`. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "table_type")

    @table_type.setter
    def table_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "table_type", value)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        All table CRUD operations must be executed on a running cluster or SQL warehouse. If a cluster_id is specified, it will be used to execute SQL commands to manage this table. If empty, a cluster will be created automatically with the name `terraform-sql-table`. Conflicts with `warehouse_id`.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="clusterKeys")
    def cluster_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        a subset of columns to liquid cluster the table by. For automatic clustering, set `cluster_keys` to `["AUTO"]`. To turn off clustering, set it to `["NONE"]`. Conflicts with `partitions`.
        """
        return pulumi.get(self, "cluster_keys")

    @cluster_keys.setter
    def cluster_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "cluster_keys", value)

    @_builtins.property
    @pulumi.getter
    def columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SqlTableColumnArgs']]]]:
        return pulumi.get(self, "columns")

    @columns.setter
    def columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SqlTableColumnArgs']]]]):
        pulumi.set(self, "columns", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User-supplied free-form text. Changing the comment is not currently supported on the `VIEW` table type.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="dataSourceFormat")
    def data_source_format(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        External tables are supported in multiple data source formats. The string constants identifying these formats are `DELTA`, `CSV`, `JSON`, `AVRO`, `PARQUET`, `ORC`, and `TEXT`. Change forces the creation of a new resource. Not supported for `MANAGED` tables or `VIEW`.
        """
        return pulumi.get(self, "data_source_format")

    @data_source_format.setter
    def data_source_format(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "data_source_format", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of table relative to parent catalog and schema. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Map of user defined table options. Change forces creation of a new resource.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "options", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User name/group name/sp application_id of the table owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter
    def partitions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        a subset of columns to partition the table by. Change forces the creation of a new resource. Conflicts with `cluster_keys`.
        """
        return pulumi.get(self, "partitions")

    @partitions.setter
    def partitions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "partitions", value)

    @_builtins.property
    @pulumi.getter
    def properties(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A map of table properties.
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "properties", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['SqlTableProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['SqlTableProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="storageCredentialName")
    def storage_credential_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        For EXTERNAL Tables only: the name of storage credential to use. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "storage_credential_name")

    @storage_credential_name.setter
    def storage_credential_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_credential_name", value)

    @_builtins.property
    @pulumi.getter(name="storageLocation")
    def storage_location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of storage location for Table data (required for EXTERNAL Tables).  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.).  Not supported for `VIEW` or `MANAGED` table_type.
        """
        return pulumi.get(self, "storage_location")

    @storage_location.setter
    def storage_location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_location", value)

    @_builtins.property
    @pulumi.getter(name="viewDefinition")
    def view_definition(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        SQL text defining the view (for `table_type == "VIEW"`). Not supported for `MANAGED` or `EXTERNAL` table_type.
        """
        return pulumi.get(self, "view_definition")

    @view_definition.setter
    def view_definition(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "view_definition", value)

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        All table CRUD operations must be executed on a running cluster or SQL warehouse. If a `warehouse_id` is specified, that SQL warehouse will be used to execute SQL commands to manage this table. Conflicts with `cluster_id`.
        """
        return pulumi.get(self, "warehouse_id")

    @warehouse_id.setter
    def warehouse_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "warehouse_id", value)


@pulumi.input_type
class _SqlTableState:
    def __init__(__self__, *,
                 catalog_name: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_keys: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 columns: Optional[pulumi.Input[Sequence[pulumi.Input['SqlTableColumnArgs']]]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 data_source_format: Optional[pulumi.Input[_builtins.str]] = None,
                 effective_properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 partitions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 provider_config: Optional[pulumi.Input['SqlTableProviderConfigArgs']] = None,
                 schema_name: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_credential_name: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_location: Optional[pulumi.Input[_builtins.str]] = None,
                 table_id: Optional[pulumi.Input[_builtins.str]] = None,
                 table_type: Optional[pulumi.Input[_builtins.str]] = None,
                 view_definition: Optional[pulumi.Input[_builtins.str]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SqlTable resources.
        :param pulumi.Input[_builtins.str] catalog_name: Name of parent catalog. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] cluster_id: All table CRUD operations must be executed on a running cluster or SQL warehouse. If a cluster_id is specified, it will be used to execute SQL commands to manage this table. If empty, a cluster will be created automatically with the name `terraform-sql-table`. Conflicts with `warehouse_id`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] cluster_keys: a subset of columns to liquid cluster the table by. For automatic clustering, set `cluster_keys` to `["AUTO"]`. To turn off clustering, set it to `["NONE"]`. Conflicts with `partitions`.
        :param pulumi.Input[_builtins.str] comment: User-supplied free-form text. Changing the comment is not currently supported on the `VIEW` table type.
        :param pulumi.Input[_builtins.str] data_source_format: External tables are supported in multiple data source formats. The string constants identifying these formats are `DELTA`, `CSV`, `JSON`, `AVRO`, `PARQUET`, `ORC`, and `TEXT`. Change forces the creation of a new resource. Not supported for `MANAGED` tables or `VIEW`.
        :param pulumi.Input[_builtins.str] name: Name of table relative to parent catalog and schema. Change forces the creation of a new resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] options: Map of user defined table options. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] owner: User name/group name/sp application_id of the table owner.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] partitions: a subset of columns to partition the table by. Change forces the creation of a new resource. Conflicts with `cluster_keys`.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] properties: A map of table properties.
        :param pulumi.Input['SqlTableProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] schema_name: Name of parent Schema relative to parent Catalog. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] storage_credential_name: For EXTERNAL Tables only: the name of storage credential to use. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] storage_location: URL of storage location for Table data (required for EXTERNAL Tables).  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.).  Not supported for `VIEW` or `MANAGED` table_type.
        :param pulumi.Input[_builtins.str] table_id: The unique identifier of the table.
        :param pulumi.Input[_builtins.str] table_type: Distinguishes a view vs. managed/external Table. `MANAGED`, `EXTERNAL` or `VIEW`. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] view_definition: SQL text defining the view (for `table_type == "VIEW"`). Not supported for `MANAGED` or `EXTERNAL` table_type.
        :param pulumi.Input[_builtins.str] warehouse_id: All table CRUD operations must be executed on a running cluster or SQL warehouse. If a `warehouse_id` is specified, that SQL warehouse will be used to execute SQL commands to manage this table. Conflicts with `cluster_id`.
        """
        if catalog_name is not None:
            pulumi.set(__self__, "catalog_name", catalog_name)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if cluster_keys is not None:
            pulumi.set(__self__, "cluster_keys", cluster_keys)
        if columns is not None:
            pulumi.set(__self__, "columns", columns)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if data_source_format is not None:
            pulumi.set(__self__, "data_source_format", data_source_format)
        if effective_properties is not None:
            pulumi.set(__self__, "effective_properties", effective_properties)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if partitions is not None:
            pulumi.set(__self__, "partitions", partitions)
        if properties is not None:
            pulumi.set(__self__, "properties", properties)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if storage_credential_name is not None:
            pulumi.set(__self__, "storage_credential_name", storage_credential_name)
        if storage_location is not None:
            pulumi.set(__self__, "storage_location", storage_location)
        if table_id is not None:
            pulumi.set(__self__, "table_id", table_id)
        if table_type is not None:
            pulumi.set(__self__, "table_type", table_type)
        if view_definition is not None:
            pulumi.set(__self__, "view_definition", view_definition)
        if warehouse_id is not None:
            pulumi.set(__self__, "warehouse_id", warehouse_id)

    @_builtins.property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of parent catalog. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "catalog_name")

    @catalog_name.setter
    def catalog_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "catalog_name", value)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        All table CRUD operations must be executed on a running cluster or SQL warehouse. If a cluster_id is specified, it will be used to execute SQL commands to manage this table. If empty, a cluster will be created automatically with the name `terraform-sql-table`. Conflicts with `warehouse_id`.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="clusterKeys")
    def cluster_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        a subset of columns to liquid cluster the table by. For automatic clustering, set `cluster_keys` to `["AUTO"]`. To turn off clustering, set it to `["NONE"]`. Conflicts with `partitions`.
        """
        return pulumi.get(self, "cluster_keys")

    @cluster_keys.setter
    def cluster_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "cluster_keys", value)

    @_builtins.property
    @pulumi.getter
    def columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SqlTableColumnArgs']]]]:
        return pulumi.get(self, "columns")

    @columns.setter
    def columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SqlTableColumnArgs']]]]):
        pulumi.set(self, "columns", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User-supplied free-form text. Changing the comment is not currently supported on the `VIEW` table type.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="dataSourceFormat")
    def data_source_format(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        External tables are supported in multiple data source formats. The string constants identifying these formats are `DELTA`, `CSV`, `JSON`, `AVRO`, `PARQUET`, `ORC`, and `TEXT`. Change forces the creation of a new resource. Not supported for `MANAGED` tables or `VIEW`.
        """
        return pulumi.get(self, "data_source_format")

    @data_source_format.setter
    def data_source_format(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "data_source_format", value)

    @_builtins.property
    @pulumi.getter(name="effectiveProperties")
    def effective_properties(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "effective_properties")

    @effective_properties.setter
    def effective_properties(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "effective_properties", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of table relative to parent catalog and schema. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Map of user defined table options. Change forces creation of a new resource.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "options", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User name/group name/sp application_id of the table owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter
    def partitions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        a subset of columns to partition the table by. Change forces the creation of a new resource. Conflicts with `cluster_keys`.
        """
        return pulumi.get(self, "partitions")

    @partitions.setter
    def partitions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "partitions", value)

    @_builtins.property
    @pulumi.getter
    def properties(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A map of table properties.
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "properties", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['SqlTableProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['SqlTableProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of parent Schema relative to parent Catalog. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "schema_name", value)

    @_builtins.property
    @pulumi.getter(name="storageCredentialName")
    def storage_credential_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        For EXTERNAL Tables only: the name of storage credential to use. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "storage_credential_name")

    @storage_credential_name.setter
    def storage_credential_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_credential_name", value)

    @_builtins.property
    @pulumi.getter(name="storageLocation")
    def storage_location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of storage location for Table data (required for EXTERNAL Tables).  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.).  Not supported for `VIEW` or `MANAGED` table_type.
        """
        return pulumi.get(self, "storage_location")

    @storage_location.setter
    def storage_location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_location", value)

    @_builtins.property
    @pulumi.getter(name="tableId")
    def table_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the table.
        """
        return pulumi.get(self, "table_id")

    @table_id.setter
    def table_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "table_id", value)

    @_builtins.property
    @pulumi.getter(name="tableType")
    def table_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Distinguishes a view vs. managed/external Table. `MANAGED`, `EXTERNAL` or `VIEW`. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "table_type")

    @table_type.setter
    def table_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "table_type", value)

    @_builtins.property
    @pulumi.getter(name="viewDefinition")
    def view_definition(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        SQL text defining the view (for `table_type == "VIEW"`). Not supported for `MANAGED` or `EXTERNAL` table_type.
        """
        return pulumi.get(self, "view_definition")

    @view_definition.setter
    def view_definition(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "view_definition", value)

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        All table CRUD operations must be executed on a running cluster or SQL warehouse. If a `warehouse_id` is specified, that SQL warehouse will be used to execute SQL commands to manage this table. Conflicts with `cluster_id`.
        """
        return pulumi.get(self, "warehouse_id")

    @warehouse_id.setter
    def warehouse_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "warehouse_id", value)


@pulumi.type_token("databricks:index/sqlTable:SqlTable")
class SqlTable(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 catalog_name: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_keys: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 columns: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SqlTableColumnArgs', 'SqlTableColumnArgsDict']]]]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 data_source_format: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 partitions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 provider_config: Optional[pulumi.Input[Union['SqlTableProviderConfigArgs', 'SqlTableProviderConfigArgsDict']]] = None,
                 schema_name: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_credential_name: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_location: Optional[pulumi.Input[_builtins.str]] = None,
                 table_type: Optional[pulumi.Input[_builtins.str]] = None,
                 view_definition: Optional[pulumi.Input[_builtins.str]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Within a metastore, Unity Catalog provides a 3-level namespace for organizing data: Catalogs, databases (also called schemas), and tables/views.

        A `SqlTable` is contained within databricks_schema, and can represent either a managed table, an external table, or a view.

        This resource creates and updates the Unity Catalog table/view by executing the necessary SQL queries on a special auto-terminating cluster it would create for this operation. You could also specify a SQL warehouse or cluster for the queries to be executed on.

        > This resource can only be used with a workspace-level provider!

        > This resource doesn't handle complex cases of schema evolution due to the limitations of Pulumi itself.  If you need to implement schema evolution it's recommended to use specialized tools, such as, [Liquibase](https://medium.com/dbsql-sme-engineering/advanced-schema-management-on-databricks-with-liquibase-1900e9f7b9c0) and [Flyway](https://medium.com/dbsql-sme-engineering/databricks-schema-management-with-flyway-527c4a9f5d67).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks
        import pulumi_std as std

        sandbox = databricks.Catalog("sandbox",
            name="sandbox",
            comment="this catalog is managed by terraform",
            properties={
                "purpose": "testing",
            })
        things = databricks.Schema("things",
            catalog_name=sandbox.id,
            name="things",
            comment="this database is managed by terraform",
            properties={
                "kind": "various",
            })
        thing = databricks.SqlTable("thing",
            name="quickstart_table",
            catalog_name=sandbox.name,
            schema_name=things.name,
            table_type="MANAGED",
            columns=[
                {
                    "name": "id",
                    "type": "int",
                },
                {
                    "name": "name",
                    "type": "string",
                    "comment": "name of thing",
                },
            ],
            comment="this table is managed by terraform")
        thing_view = databricks.SqlTable("thing_view",
            name="quickstart_table_view",
            catalog_name=sandbox.name,
            schema_name=things.name,
            table_type="VIEW",
            cluster_id="0423-201305-xsrt82qn",
            view_definition=std.format(input="SELECT name FROM %s WHERE id == 1",
                args=[thing.id]).result,
            comment="this view is managed by terraform")
        ```

        ### Use an existing warehouse to create a table

        ```python
        import pulumi
        import pulumi_databricks as databricks
        import pulumi_std as std

        this = databricks.SqlEndpoint("this",
            name="endpoint",
            cluster_size="2X-Small",
            max_num_clusters=1)
        thing = databricks.SqlTable("thing",
            name="quickstart_table",
            catalog_name=sandbox["name"],
            schema_name=things["name"],
            table_type="MANAGED",
            warehouse_id=this.id,
            columns=[
                {
                    "name": "id",
                    "type": "int",
                },
                {
                    "name": "name",
                    "type": "string",
                    "comment": "name of thing",
                },
            ],
            comment="this table is managed by terraform")
        thing_view = databricks.SqlTable("thing_view",
            name="quickstart_table_view",
            catalog_name=sandbox["name"],
            schema_name=things["name"],
            table_type="VIEW",
            warehouse_id=this.id,
            view_definition=std.format(input="SELECT name FROM %s WHERE id == 1",
                args=[thing.id]).result,
            comment="this view is managed by terraform")
        ```

        ## Use an Identity Column

        ```python
        import pulumi
        import pulumi_databricks as databricks

        sandbox = databricks.Catalog("sandbox",
            name="sandbox",
            comment="this catalog is managed by terraform",
            properties={
                "purpose": "testing",
            })
        things = databricks.Schema("things",
            catalog_name=sandbox.id,
            name="things",
            comment="this database is managed by terraform",
            properties={
                "kind": "various",
            })
        thing = databricks.SqlTable("thing",
            name="identity_table",
            catalog_name=sandbox.name,
            schema_name=things.name,
            table_type="MANAGED",
            columns=[
                {
                    "name": "id",
                    "type": "bigint",
                    "identity": "default",
                },
                {
                    "name": "name",
                    "type": "string",
                    "comment": "name of thing",
                },
            ],
            comment="this table is managed by terraform")
        ```

        ## Enable automatic clustering

        ```python
        import pulumi
        import pulumi_databricks as databricks

        thing = databricks.SqlTable("thing",
            name="auto_cluster_table",
            catalog_name=sandbox["name"],
            schema_name=things["name"],
            table_type="MANAGED",
            cluster_keys=["AUTO"],
            columns=[{
                "name": "name",
                "type": "string",
                "comment": "name of thing",
            }],
            comment="this table is managed by terraform")
        ```

        ## Migration from `Table`

        The `Table` resource has been deprecated in favor of `SqlTable`. To migrate from `Table` to `SqlTable`:

        1. Define a `SqlTable` resource with arguments corresponding to `Table`.
        2. Add a `removed` block to remove the `Table` resource without deleting the existing table by using the `lifecycle` block. If you're using Pulumi version below v1.7.0, you will need to use the `terraform state rm` command instead.
        3. Add an `import` block to add the `SqlTable` resource, corresponding to the existing table. If you're using Pulumi version below v1.5.0, you will need to use `pulumi import` command instead.

        For example, suppose we have the following `Table` resource:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.Table("this",
            catalog_name="catalog",
            schema_name="schema",
            name="table",
            table_type="MANAGED",
            data_source_format="DELTA",
            columns=[{
                "name": "col1",
                "type_name": "STRING",
                "type_json": "{\\"type\\":\\"STRING\\"}",
                "comment": "comment",
                "nullable": True,
            }],
            comment="comment",
            properties={
                "key": "value",
            })
        ```

        The migration would look like this:

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] catalog_name: Name of parent catalog. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] cluster_id: All table CRUD operations must be executed on a running cluster or SQL warehouse. If a cluster_id is specified, it will be used to execute SQL commands to manage this table. If empty, a cluster will be created automatically with the name `terraform-sql-table`. Conflicts with `warehouse_id`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] cluster_keys: a subset of columns to liquid cluster the table by. For automatic clustering, set `cluster_keys` to `["AUTO"]`. To turn off clustering, set it to `["NONE"]`. Conflicts with `partitions`.
        :param pulumi.Input[_builtins.str] comment: User-supplied free-form text. Changing the comment is not currently supported on the `VIEW` table type.
        :param pulumi.Input[_builtins.str] data_source_format: External tables are supported in multiple data source formats. The string constants identifying these formats are `DELTA`, `CSV`, `JSON`, `AVRO`, `PARQUET`, `ORC`, and `TEXT`. Change forces the creation of a new resource. Not supported for `MANAGED` tables or `VIEW`.
        :param pulumi.Input[_builtins.str] name: Name of table relative to parent catalog and schema. Change forces the creation of a new resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] options: Map of user defined table options. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] owner: User name/group name/sp application_id of the table owner.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] partitions: a subset of columns to partition the table by. Change forces the creation of a new resource. Conflicts with `cluster_keys`.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] properties: A map of table properties.
        :param pulumi.Input[Union['SqlTableProviderConfigArgs', 'SqlTableProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] schema_name: Name of parent Schema relative to parent Catalog. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] storage_credential_name: For EXTERNAL Tables only: the name of storage credential to use. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] storage_location: URL of storage location for Table data (required for EXTERNAL Tables).  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.).  Not supported for `VIEW` or `MANAGED` table_type.
        :param pulumi.Input[_builtins.str] table_type: Distinguishes a view vs. managed/external Table. `MANAGED`, `EXTERNAL` or `VIEW`. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] view_definition: SQL text defining the view (for `table_type == "VIEW"`). Not supported for `MANAGED` or `EXTERNAL` table_type.
        :param pulumi.Input[_builtins.str] warehouse_id: All table CRUD operations must be executed on a running cluster or SQL warehouse. If a `warehouse_id` is specified, that SQL warehouse will be used to execute SQL commands to manage this table. Conflicts with `cluster_id`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SqlTableArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Within a metastore, Unity Catalog provides a 3-level namespace for organizing data: Catalogs, databases (also called schemas), and tables/views.

        A `SqlTable` is contained within databricks_schema, and can represent either a managed table, an external table, or a view.

        This resource creates and updates the Unity Catalog table/view by executing the necessary SQL queries on a special auto-terminating cluster it would create for this operation. You could also specify a SQL warehouse or cluster for the queries to be executed on.

        > This resource can only be used with a workspace-level provider!

        > This resource doesn't handle complex cases of schema evolution due to the limitations of Pulumi itself.  If you need to implement schema evolution it's recommended to use specialized tools, such as, [Liquibase](https://medium.com/dbsql-sme-engineering/advanced-schema-management-on-databricks-with-liquibase-1900e9f7b9c0) and [Flyway](https://medium.com/dbsql-sme-engineering/databricks-schema-management-with-flyway-527c4a9f5d67).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks
        import pulumi_std as std

        sandbox = databricks.Catalog("sandbox",
            name="sandbox",
            comment="this catalog is managed by terraform",
            properties={
                "purpose": "testing",
            })
        things = databricks.Schema("things",
            catalog_name=sandbox.id,
            name="things",
            comment="this database is managed by terraform",
            properties={
                "kind": "various",
            })
        thing = databricks.SqlTable("thing",
            name="quickstart_table",
            catalog_name=sandbox.name,
            schema_name=things.name,
            table_type="MANAGED",
            columns=[
                {
                    "name": "id",
                    "type": "int",
                },
                {
                    "name": "name",
                    "type": "string",
                    "comment": "name of thing",
                },
            ],
            comment="this table is managed by terraform")
        thing_view = databricks.SqlTable("thing_view",
            name="quickstart_table_view",
            catalog_name=sandbox.name,
            schema_name=things.name,
            table_type="VIEW",
            cluster_id="0423-201305-xsrt82qn",
            view_definition=std.format(input="SELECT name FROM %s WHERE id == 1",
                args=[thing.id]).result,
            comment="this view is managed by terraform")
        ```

        ### Use an existing warehouse to create a table

        ```python
        import pulumi
        import pulumi_databricks as databricks
        import pulumi_std as std

        this = databricks.SqlEndpoint("this",
            name="endpoint",
            cluster_size="2X-Small",
            max_num_clusters=1)
        thing = databricks.SqlTable("thing",
            name="quickstart_table",
            catalog_name=sandbox["name"],
            schema_name=things["name"],
            table_type="MANAGED",
            warehouse_id=this.id,
            columns=[
                {
                    "name": "id",
                    "type": "int",
                },
                {
                    "name": "name",
                    "type": "string",
                    "comment": "name of thing",
                },
            ],
            comment="this table is managed by terraform")
        thing_view = databricks.SqlTable("thing_view",
            name="quickstart_table_view",
            catalog_name=sandbox["name"],
            schema_name=things["name"],
            table_type="VIEW",
            warehouse_id=this.id,
            view_definition=std.format(input="SELECT name FROM %s WHERE id == 1",
                args=[thing.id]).result,
            comment="this view is managed by terraform")
        ```

        ## Use an Identity Column

        ```python
        import pulumi
        import pulumi_databricks as databricks

        sandbox = databricks.Catalog("sandbox",
            name="sandbox",
            comment="this catalog is managed by terraform",
            properties={
                "purpose": "testing",
            })
        things = databricks.Schema("things",
            catalog_name=sandbox.id,
            name="things",
            comment="this database is managed by terraform",
            properties={
                "kind": "various",
            })
        thing = databricks.SqlTable("thing",
            name="identity_table",
            catalog_name=sandbox.name,
            schema_name=things.name,
            table_type="MANAGED",
            columns=[
                {
                    "name": "id",
                    "type": "bigint",
                    "identity": "default",
                },
                {
                    "name": "name",
                    "type": "string",
                    "comment": "name of thing",
                },
            ],
            comment="this table is managed by terraform")
        ```

        ## Enable automatic clustering

        ```python
        import pulumi
        import pulumi_databricks as databricks

        thing = databricks.SqlTable("thing",
            name="auto_cluster_table",
            catalog_name=sandbox["name"],
            schema_name=things["name"],
            table_type="MANAGED",
            cluster_keys=["AUTO"],
            columns=[{
                "name": "name",
                "type": "string",
                "comment": "name of thing",
            }],
            comment="this table is managed by terraform")
        ```

        ## Migration from `Table`

        The `Table` resource has been deprecated in favor of `SqlTable`. To migrate from `Table` to `SqlTable`:

        1. Define a `SqlTable` resource with arguments corresponding to `Table`.
        2. Add a `removed` block to remove the `Table` resource without deleting the existing table by using the `lifecycle` block. If you're using Pulumi version below v1.7.0, you will need to use the `terraform state rm` command instead.
        3. Add an `import` block to add the `SqlTable` resource, corresponding to the existing table. If you're using Pulumi version below v1.5.0, you will need to use `pulumi import` command instead.

        For example, suppose we have the following `Table` resource:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.Table("this",
            catalog_name="catalog",
            schema_name="schema",
            name="table",
            table_type="MANAGED",
            data_source_format="DELTA",
            columns=[{
                "name": "col1",
                "type_name": "STRING",
                "type_json": "{\\"type\\":\\"STRING\\"}",
                "comment": "comment",
                "nullable": True,
            }],
            comment="comment",
            properties={
                "key": "value",
            })
        ```

        The migration would look like this:

        :param str resource_name: The name of the resource.
        :param SqlTableArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SqlTableArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 catalog_name: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_keys: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 columns: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SqlTableColumnArgs', 'SqlTableColumnArgsDict']]]]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 data_source_format: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 partitions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 provider_config: Optional[pulumi.Input[Union['SqlTableProviderConfigArgs', 'SqlTableProviderConfigArgsDict']]] = None,
                 schema_name: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_credential_name: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_location: Optional[pulumi.Input[_builtins.str]] = None,
                 table_type: Optional[pulumi.Input[_builtins.str]] = None,
                 view_definition: Optional[pulumi.Input[_builtins.str]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SqlTableArgs.__new__(SqlTableArgs)

            if catalog_name is None and not opts.urn:
                raise TypeError("Missing required property 'catalog_name'")
            __props__.__dict__["catalog_name"] = catalog_name
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["cluster_keys"] = cluster_keys
            __props__.__dict__["columns"] = columns
            __props__.__dict__["comment"] = comment
            __props__.__dict__["data_source_format"] = data_source_format
            __props__.__dict__["name"] = name
            __props__.__dict__["options"] = options
            __props__.__dict__["owner"] = owner
            __props__.__dict__["partitions"] = partitions
            __props__.__dict__["properties"] = properties
            __props__.__dict__["provider_config"] = provider_config
            if schema_name is None and not opts.urn:
                raise TypeError("Missing required property 'schema_name'")
            __props__.__dict__["schema_name"] = schema_name
            __props__.__dict__["storage_credential_name"] = storage_credential_name
            __props__.__dict__["storage_location"] = storage_location
            if table_type is None and not opts.urn:
                raise TypeError("Missing required property 'table_type'")
            __props__.__dict__["table_type"] = table_type
            __props__.__dict__["view_definition"] = view_definition
            __props__.__dict__["warehouse_id"] = warehouse_id
            __props__.__dict__["effective_properties"] = None
            __props__.__dict__["table_id"] = None
        super(SqlTable, __self__).__init__(
            'databricks:index/sqlTable:SqlTable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            catalog_name: Optional[pulumi.Input[_builtins.str]] = None,
            cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
            cluster_keys: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            columns: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SqlTableColumnArgs', 'SqlTableColumnArgsDict']]]]] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            data_source_format: Optional[pulumi.Input[_builtins.str]] = None,
            effective_properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            owner: Optional[pulumi.Input[_builtins.str]] = None,
            partitions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            provider_config: Optional[pulumi.Input[Union['SqlTableProviderConfigArgs', 'SqlTableProviderConfigArgsDict']]] = None,
            schema_name: Optional[pulumi.Input[_builtins.str]] = None,
            storage_credential_name: Optional[pulumi.Input[_builtins.str]] = None,
            storage_location: Optional[pulumi.Input[_builtins.str]] = None,
            table_id: Optional[pulumi.Input[_builtins.str]] = None,
            table_type: Optional[pulumi.Input[_builtins.str]] = None,
            view_definition: Optional[pulumi.Input[_builtins.str]] = None,
            warehouse_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'SqlTable':
        """
        Get an existing SqlTable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] catalog_name: Name of parent catalog. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] cluster_id: All table CRUD operations must be executed on a running cluster or SQL warehouse. If a cluster_id is specified, it will be used to execute SQL commands to manage this table. If empty, a cluster will be created automatically with the name `terraform-sql-table`. Conflicts with `warehouse_id`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] cluster_keys: a subset of columns to liquid cluster the table by. For automatic clustering, set `cluster_keys` to `["AUTO"]`. To turn off clustering, set it to `["NONE"]`. Conflicts with `partitions`.
        :param pulumi.Input[_builtins.str] comment: User-supplied free-form text. Changing the comment is not currently supported on the `VIEW` table type.
        :param pulumi.Input[_builtins.str] data_source_format: External tables are supported in multiple data source formats. The string constants identifying these formats are `DELTA`, `CSV`, `JSON`, `AVRO`, `PARQUET`, `ORC`, and `TEXT`. Change forces the creation of a new resource. Not supported for `MANAGED` tables or `VIEW`.
        :param pulumi.Input[_builtins.str] name: Name of table relative to parent catalog and schema. Change forces the creation of a new resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] options: Map of user defined table options. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] owner: User name/group name/sp application_id of the table owner.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] partitions: a subset of columns to partition the table by. Change forces the creation of a new resource. Conflicts with `cluster_keys`.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] properties: A map of table properties.
        :param pulumi.Input[Union['SqlTableProviderConfigArgs', 'SqlTableProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] schema_name: Name of parent Schema relative to parent Catalog. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] storage_credential_name: For EXTERNAL Tables only: the name of storage credential to use. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] storage_location: URL of storage location for Table data (required for EXTERNAL Tables).  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.).  Not supported for `VIEW` or `MANAGED` table_type.
        :param pulumi.Input[_builtins.str] table_id: The unique identifier of the table.
        :param pulumi.Input[_builtins.str] table_type: Distinguishes a view vs. managed/external Table. `MANAGED`, `EXTERNAL` or `VIEW`. Change forces the creation of a new resource.
        :param pulumi.Input[_builtins.str] view_definition: SQL text defining the view (for `table_type == "VIEW"`). Not supported for `MANAGED` or `EXTERNAL` table_type.
        :param pulumi.Input[_builtins.str] warehouse_id: All table CRUD operations must be executed on a running cluster or SQL warehouse. If a `warehouse_id` is specified, that SQL warehouse will be used to execute SQL commands to manage this table. Conflicts with `cluster_id`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SqlTableState.__new__(_SqlTableState)

        __props__.__dict__["catalog_name"] = catalog_name
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["cluster_keys"] = cluster_keys
        __props__.__dict__["columns"] = columns
        __props__.__dict__["comment"] = comment
        __props__.__dict__["data_source_format"] = data_source_format
        __props__.__dict__["effective_properties"] = effective_properties
        __props__.__dict__["name"] = name
        __props__.__dict__["options"] = options
        __props__.__dict__["owner"] = owner
        __props__.__dict__["partitions"] = partitions
        __props__.__dict__["properties"] = properties
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["schema_name"] = schema_name
        __props__.__dict__["storage_credential_name"] = storage_credential_name
        __props__.__dict__["storage_location"] = storage_location
        __props__.__dict__["table_id"] = table_id
        __props__.__dict__["table_type"] = table_type
        __props__.__dict__["view_definition"] = view_definition
        __props__.__dict__["warehouse_id"] = warehouse_id
        return SqlTable(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of parent catalog. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "catalog_name")

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[_builtins.str]:
        """
        All table CRUD operations must be executed on a running cluster or SQL warehouse. If a cluster_id is specified, it will be used to execute SQL commands to manage this table. If empty, a cluster will be created automatically with the name `terraform-sql-table`. Conflicts with `warehouse_id`.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter(name="clusterKeys")
    def cluster_keys(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        a subset of columns to liquid cluster the table by. For automatic clustering, set `cluster_keys` to `["AUTO"]`. To turn off clustering, set it to `["NONE"]`. Conflicts with `partitions`.
        """
        return pulumi.get(self, "cluster_keys")

    @_builtins.property
    @pulumi.getter
    def columns(self) -> pulumi.Output[Sequence['outputs.SqlTableColumn']]:
        return pulumi.get(self, "columns")

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        User-supplied free-form text. Changing the comment is not currently supported on the `VIEW` table type.
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter(name="dataSourceFormat")
    def data_source_format(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        External tables are supported in multiple data source formats. The string constants identifying these formats are `DELTA`, `CSV`, `JSON`, `AVRO`, `PARQUET`, `ORC`, and `TEXT`. Change forces the creation of a new resource. Not supported for `MANAGED` tables or `VIEW`.
        """
        return pulumi.get(self, "data_source_format")

    @_builtins.property
    @pulumi.getter(name="effectiveProperties")
    def effective_properties(self) -> pulumi.Output[Mapping[str, _builtins.str]]:
        return pulumi.get(self, "effective_properties")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of table relative to parent catalog and schema. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def options(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        Map of user defined table options. Change forces creation of a new resource.
        """
        return pulumi.get(self, "options")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> pulumi.Output[_builtins.str]:
        """
        User name/group name/sp application_id of the table owner.
        """
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter
    def partitions(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        a subset of columns to partition the table by. Change forces the creation of a new resource. Conflicts with `cluster_keys`.
        """
        return pulumi.get(self, "partitions")

    @_builtins.property
    @pulumi.getter
    def properties(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        A map of table properties.
        """
        return pulumi.get(self, "properties")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.SqlTableProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of parent Schema relative to parent Catalog. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "schema_name")

    @_builtins.property
    @pulumi.getter(name="storageCredentialName")
    def storage_credential_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        For EXTERNAL Tables only: the name of storage credential to use. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "storage_credential_name")

    @_builtins.property
    @pulumi.getter(name="storageLocation")
    def storage_location(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        URL of storage location for Table data (required for EXTERNAL Tables).  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.).  Not supported for `VIEW` or `MANAGED` table_type.
        """
        return pulumi.get(self, "storage_location")

    @_builtins.property
    @pulumi.getter(name="tableId")
    def table_id(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the table.
        """
        return pulumi.get(self, "table_id")

    @_builtins.property
    @pulumi.getter(name="tableType")
    def table_type(self) -> pulumi.Output[_builtins.str]:
        """
        Distinguishes a view vs. managed/external Table. `MANAGED`, `EXTERNAL` or `VIEW`. Change forces the creation of a new resource.
        """
        return pulumi.get(self, "table_type")

    @_builtins.property
    @pulumi.getter(name="viewDefinition")
    def view_definition(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        SQL text defining the view (for `table_type == "VIEW"`). Not supported for `MANAGED` or `EXTERNAL` table_type.
        """
        return pulumi.get(self, "view_definition")

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        All table CRUD operations must be executed on a running cluster or SQL warehouse. If a `warehouse_id` is specified, that SQL warehouse will be used to execute SQL commands to manage this table. Conflicts with `cluster_id`.
        """
        return pulumi.get(self, "warehouse_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetEndpointResult',
    'AwaitableGetEndpointResult',
    'get_endpoint',
    'get_endpoint_output',
]

@pulumi.output_type
class GetEndpointResult:
    """
    A collection of values returned by getEndpoint.
    """
    def __init__(__self__, account_id=None, azure_private_endpoint_info=None, create_time=None, display_name=None, endpoint_id=None, id=None, name=None, region=None, state=None, use_case=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if azure_private_endpoint_info and not isinstance(azure_private_endpoint_info, dict):
            raise TypeError("Expected argument 'azure_private_endpoint_info' to be a dict")
        pulumi.set(__self__, "azure_private_endpoint_info", azure_private_endpoint_info)
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if endpoint_id and not isinstance(endpoint_id, str):
            raise TypeError("Expected argument 'endpoint_id' to be a str")
        pulumi.set(__self__, "endpoint_id", endpoint_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if use_case and not isinstance(use_case, str):
            raise TypeError("Expected argument 'use_case' to be a str")
        pulumi.set(__self__, "use_case", use_case)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> _builtins.str:
        """
        (string) - The Databricks Account in which the endpoint object exists
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="azurePrivateEndpointInfo")
    def azure_private_endpoint_info(self) -> 'outputs.GetEndpointAzurePrivateEndpointInfoResult':
        """
        (AzurePrivateEndpointInfo) - Info for an Azure private endpoint
        """
        return pulumi.get(self, "azure_private_endpoint_info")

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> _builtins.str:
        """
        (string) - The timestamp when the endpoint was created. The timestamp is in RFC 3339 format in UTC timezone
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        (string) - The human-readable display name of this endpoint.
        The input should conform to RFC-1034, which restricts to letters, numbers, and hyphens,
        with the first character a letter, the last a letter or a number, and a 63 character maximum
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> _builtins.str:
        """
        (string) - The unique identifier for this endpoint under the account. This field is a UUID generated by Databricks
        """
        return pulumi.get(self, "endpoint_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - The resource name of the endpoint, which uniquely identifies the endpoint
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        (string) - The cloud provider region where this endpoint is located
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def state(self) -> _builtins.str:
        """
        (string) - The state of the endpoint. The endpoint can only be used if the state is `APPROVED`. Possible values are: `APPROVED`, `DISCONNECTED`, `FAILED`, `PENDING`
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter(name="useCase")
    def use_case(self) -> _builtins.str:
        """
        (string) - The use case that determines the type of network connectivity this endpoint provides.
        This field is automatically determined based on the endpoint configuration and cloud-specific settings. Possible values are: `SERVICE_DIRECT`
        """
        return pulumi.get(self, "use_case")


class AwaitableGetEndpointResult(GetEndpointResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointResult(
            account_id=self.account_id,
            azure_private_endpoint_info=self.azure_private_endpoint_info,
            create_time=self.create_time,
            display_name=self.display_name,
            endpoint_id=self.endpoint_id,
            id=self.id,
            name=self.name,
            region=self.region,
            state=self.state,
            use_case=self.use_case)


def get_endpoint(name: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndpointResult:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    Endpoint datasource retrieves information about a single network connectivity endpoint for private access to Databricks workspaces.

    > **Note** This resource can only be used with an account-level provider!

    ## Example Usage

    ### Example for Azure cloud
    This is an example for getting an endpoint in Azure cloud:


    :param _builtins.str name: The resource name of the endpoint, which uniquely identifies the endpoint
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getEndpoint:getEndpoint', __args__, opts=opts, typ=GetEndpointResult).value

    return AwaitableGetEndpointResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        azure_private_endpoint_info=pulumi.get(__ret__, 'azure_private_endpoint_info'),
        create_time=pulumi.get(__ret__, 'create_time'),
        display_name=pulumi.get(__ret__, 'display_name'),
        endpoint_id=pulumi.get(__ret__, 'endpoint_id'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        region=pulumi.get(__ret__, 'region'),
        state=pulumi.get(__ret__, 'state'),
        use_case=pulumi.get(__ret__, 'use_case'))
def get_endpoint_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEndpointResult]:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    Endpoint datasource retrieves information about a single network connectivity endpoint for private access to Databricks workspaces.

    > **Note** This resource can only be used with an account-level provider!

    ## Example Usage

    ### Example for Azure cloud
    This is an example for getting an endpoint in Azure cloud:


    :param _builtins.str name: The resource name of the endpoint, which uniquely identifies the endpoint
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getEndpoint:getEndpoint', __args__, opts=opts, typ=GetEndpointResult)
    return __ret__.apply(lambda __response__: GetEndpointResult(
        account_id=pulumi.get(__response__, 'account_id'),
        azure_private_endpoint_info=pulumi.get(__response__, 'azure_private_endpoint_info'),
        create_time=pulumi.get(__response__, 'create_time'),
        display_name=pulumi.get(__response__, 'display_name'),
        endpoint_id=pulumi.get(__response__, 'endpoint_id'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        region=pulumi.get(__response__, 'region'),
        state=pulumi.get(__response__, 'state'),
        use_case=pulumi.get(__response__, 'use_case')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AppsSettingsCustomTemplateArgs', 'AppsSettingsCustomTemplate']

@pulumi.input_type
class AppsSettingsCustomTemplateArgs:
    def __init__(__self__, *,
                 git_provider: pulumi.Input[_builtins.str],
                 git_repo: pulumi.Input[_builtins.str],
                 manifest: pulumi.Input['AppsSettingsCustomTemplateManifestArgs'],
                 path: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['AppsSettingsCustomTemplateProviderConfigArgs']] = None):
        """
        The set of arguments for constructing a AppsSettingsCustomTemplate resource.
        :param pulumi.Input[_builtins.str] git_provider: The Git provider of the template
        :param pulumi.Input[_builtins.str] git_repo: The Git repository URL that the template resides in
        :param pulumi.Input['AppsSettingsCustomTemplateManifestArgs'] manifest: The manifest of the template. It defines fields and default values when installing the template
        :param pulumi.Input[_builtins.str] path: The path to the template within the Git repository
        :param pulumi.Input[_builtins.str] description: The description of the template
        :param pulumi.Input[_builtins.str] name: The name of the template. It must contain only alphanumeric characters, hyphens, underscores, and whitespaces.
               It must be unique within the workspace
        :param pulumi.Input['AppsSettingsCustomTemplateProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        """
        pulumi.set(__self__, "git_provider", git_provider)
        pulumi.set(__self__, "git_repo", git_repo)
        pulumi.set(__self__, "manifest", manifest)
        pulumi.set(__self__, "path", path)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter(name="gitProvider")
    def git_provider(self) -> pulumi.Input[_builtins.str]:
        """
        The Git provider of the template
        """
        return pulumi.get(self, "git_provider")

    @git_provider.setter
    def git_provider(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "git_provider", value)

    @_builtins.property
    @pulumi.getter(name="gitRepo")
    def git_repo(self) -> pulumi.Input[_builtins.str]:
        """
        The Git repository URL that the template resides in
        """
        return pulumi.get(self, "git_repo")

    @git_repo.setter
    def git_repo(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "git_repo", value)

    @_builtins.property
    @pulumi.getter
    def manifest(self) -> pulumi.Input['AppsSettingsCustomTemplateManifestArgs']:
        """
        The manifest of the template. It defines fields and default values when installing the template
        """
        return pulumi.get(self, "manifest")

    @manifest.setter
    def manifest(self, value: pulumi.Input['AppsSettingsCustomTemplateManifestArgs']):
        pulumi.set(self, "manifest", value)

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Input[_builtins.str]:
        """
        The path to the template within the Git repository
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the template
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the template. It must contain only alphanumeric characters, hyphens, underscores, and whitespaces.
        It must be unique within the workspace
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['AppsSettingsCustomTemplateProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['AppsSettingsCustomTemplateProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)


@pulumi.input_type
class _AppsSettingsCustomTemplateState:
    def __init__(__self__, *,
                 creator: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 git_repo: Optional[pulumi.Input[_builtins.str]] = None,
                 manifest: Optional[pulumi.Input['AppsSettingsCustomTemplateManifestArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['AppsSettingsCustomTemplateProviderConfigArgs']] = None):
        """
        Input properties used for looking up and filtering AppsSettingsCustomTemplate resources.
        :param pulumi.Input[_builtins.str] creator: (string)
        :param pulumi.Input[_builtins.str] description: The description of the template
        :param pulumi.Input[_builtins.str] git_provider: The Git provider of the template
        :param pulumi.Input[_builtins.str] git_repo: The Git repository URL that the template resides in
        :param pulumi.Input['AppsSettingsCustomTemplateManifestArgs'] manifest: The manifest of the template. It defines fields and default values when installing the template
        :param pulumi.Input[_builtins.str] name: The name of the template. It must contain only alphanumeric characters, hyphens, underscores, and whitespaces.
               It must be unique within the workspace
        :param pulumi.Input[_builtins.str] path: The path to the template within the Git repository
        :param pulumi.Input['AppsSettingsCustomTemplateProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        """
        if creator is not None:
            pulumi.set(__self__, "creator", creator)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if git_provider is not None:
            pulumi.set(__self__, "git_provider", git_provider)
        if git_repo is not None:
            pulumi.set(__self__, "git_repo", git_repo)
        if manifest is not None:
            pulumi.set(__self__, "manifest", manifest)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter
    def creator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string)
        """
        return pulumi.get(self, "creator")

    @creator.setter
    def creator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creator", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the template
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="gitProvider")
    def git_provider(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Git provider of the template
        """
        return pulumi.get(self, "git_provider")

    @git_provider.setter
    def git_provider(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_provider", value)

    @_builtins.property
    @pulumi.getter(name="gitRepo")
    def git_repo(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Git repository URL that the template resides in
        """
        return pulumi.get(self, "git_repo")

    @git_repo.setter
    def git_repo(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_repo", value)

    @_builtins.property
    @pulumi.getter
    def manifest(self) -> Optional[pulumi.Input['AppsSettingsCustomTemplateManifestArgs']]:
        """
        The manifest of the template. It defines fields and default values when installing the template
        """
        return pulumi.get(self, "manifest")

    @manifest.setter
    def manifest(self, value: Optional[pulumi.Input['AppsSettingsCustomTemplateManifestArgs']]):
        pulumi.set(self, "manifest", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the template. It must contain only alphanumeric characters, hyphens, underscores, and whitespaces.
        It must be unique within the workspace
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path to the template within the Git repository
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['AppsSettingsCustomTemplateProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['AppsSettingsCustomTemplateProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)


@pulumi.type_token("databricks:index/appsSettingsCustomTemplate:AppsSettingsCustomTemplate")
class AppsSettingsCustomTemplate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 git_repo: Optional[pulumi.Input[_builtins.str]] = None,
                 manifest: Optional[pulumi.Input[Union['AppsSettingsCustomTemplateManifestArgs', 'AppsSettingsCustomTemplateManifestArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['AppsSettingsCustomTemplateProviderConfigArgs', 'AppsSettingsCustomTemplateProviderConfigArgsDict']]] = None,
                 __props__=None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Custom App Templates store the metadata of custom app code hosted in an external Git repository, enabling users to reuse boilerplate code when creating apps.

        ## Example Usage

        ### Basic Example

        This example creates a Custom Template in the workspace with the specified name.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.AppsSettingsCustomTemplate("this",
            name="my-custom-template",
            description="A sample custom app template",
            git_repo="https://github.com/example/repo.git",
            path="path-to-template",
            git_provider="github",
            manifest={
                "version": 1,
                "name": "my-custom-app",
            })
        ```

        ### Example with API Scopes

        This example creates a custom template that declares required user API scopes.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        api_scopes_example = databricks.AppsSettingsCustomTemplate("api_scopes_example",
            name="my-api-template",
            description="A template that requests user API scopes",
            git_repo="https://github.com/example/my-app.git",
            path="templates/app",
            git_provider="github",
            manifest={
                "version": 1,
                "name": "my-databricks-app",
                "description": "This app requires the SQL API scope.",
                "user_api_scopes": ["sql"],
            })
        ```

        ### Example with Resource Requirements

        This example defines a template that requests specific workspace resources with permissions granted.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        resources_example = databricks.AppsSettingsCustomTemplate("resources_example",
            name="my-resource-template",
            description="Template that requires secret and SQL warehouse access",
            git_repo="https://github.com/example/resource-app.git",
            path="resource-template",
            git_provider="github",
            manifest={
                "version": 1,
                "name": "resource-consuming-app",
                "description": "This app requires access to a secret and SQL warehouse.",
                "resource_specs": [
                    {
                        "name": "my-secret",
                        "description": "A secret needed by the app",
                        "secret_spec": {
                            "permission": "READ",
                        },
                    },
                    {
                        "name": "warehouse",
                        "description": "Warehouse access",
                        "sql_warehouse_spec": {
                            "permission": "CAN_USE",
                        },
                    },
                ],
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of the template
        :param pulumi.Input[_builtins.str] git_provider: The Git provider of the template
        :param pulumi.Input[_builtins.str] git_repo: The Git repository URL that the template resides in
        :param pulumi.Input[Union['AppsSettingsCustomTemplateManifestArgs', 'AppsSettingsCustomTemplateManifestArgsDict']] manifest: The manifest of the template. It defines fields and default values when installing the template
        :param pulumi.Input[_builtins.str] name: The name of the template. It must contain only alphanumeric characters, hyphens, underscores, and whitespaces.
               It must be unique within the workspace
        :param pulumi.Input[_builtins.str] path: The path to the template within the Git repository
        :param pulumi.Input[Union['AppsSettingsCustomTemplateProviderConfigArgs', 'AppsSettingsCustomTemplateProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AppsSettingsCustomTemplateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Custom App Templates store the metadata of custom app code hosted in an external Git repository, enabling users to reuse boilerplate code when creating apps.

        ## Example Usage

        ### Basic Example

        This example creates a Custom Template in the workspace with the specified name.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.AppsSettingsCustomTemplate("this",
            name="my-custom-template",
            description="A sample custom app template",
            git_repo="https://github.com/example/repo.git",
            path="path-to-template",
            git_provider="github",
            manifest={
                "version": 1,
                "name": "my-custom-app",
            })
        ```

        ### Example with API Scopes

        This example creates a custom template that declares required user API scopes.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        api_scopes_example = databricks.AppsSettingsCustomTemplate("api_scopes_example",
            name="my-api-template",
            description="A template that requests user API scopes",
            git_repo="https://github.com/example/my-app.git",
            path="templates/app",
            git_provider="github",
            manifest={
                "version": 1,
                "name": "my-databricks-app",
                "description": "This app requires the SQL API scope.",
                "user_api_scopes": ["sql"],
            })
        ```

        ### Example with Resource Requirements

        This example defines a template that requests specific workspace resources with permissions granted.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        resources_example = databricks.AppsSettingsCustomTemplate("resources_example",
            name="my-resource-template",
            description="Template that requires secret and SQL warehouse access",
            git_repo="https://github.com/example/resource-app.git",
            path="resource-template",
            git_provider="github",
            manifest={
                "version": 1,
                "name": "resource-consuming-app",
                "description": "This app requires access to a secret and SQL warehouse.",
                "resource_specs": [
                    {
                        "name": "my-secret",
                        "description": "A secret needed by the app",
                        "secret_spec": {
                            "permission": "READ",
                        },
                    },
                    {
                        "name": "warehouse",
                        "description": "Warehouse access",
                        "sql_warehouse_spec": {
                            "permission": "CAN_USE",
                        },
                    },
                ],
            })
        ```

        :param str resource_name: The name of the resource.
        :param AppsSettingsCustomTemplateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppsSettingsCustomTemplateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 git_repo: Optional[pulumi.Input[_builtins.str]] = None,
                 manifest: Optional[pulumi.Input[Union['AppsSettingsCustomTemplateManifestArgs', 'AppsSettingsCustomTemplateManifestArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['AppsSettingsCustomTemplateProviderConfigArgs', 'AppsSettingsCustomTemplateProviderConfigArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppsSettingsCustomTemplateArgs.__new__(AppsSettingsCustomTemplateArgs)

            __props__.__dict__["description"] = description
            if git_provider is None and not opts.urn:
                raise TypeError("Missing required property 'git_provider'")
            __props__.__dict__["git_provider"] = git_provider
            if git_repo is None and not opts.urn:
                raise TypeError("Missing required property 'git_repo'")
            __props__.__dict__["git_repo"] = git_repo
            if manifest is None and not opts.urn:
                raise TypeError("Missing required property 'manifest'")
            __props__.__dict__["manifest"] = manifest
            __props__.__dict__["name"] = name
            if path is None and not opts.urn:
                raise TypeError("Missing required property 'path'")
            __props__.__dict__["path"] = path
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["creator"] = None
        super(AppsSettingsCustomTemplate, __self__).__init__(
            'databricks:index/appsSettingsCustomTemplate:AppsSettingsCustomTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            creator: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            git_provider: Optional[pulumi.Input[_builtins.str]] = None,
            git_repo: Optional[pulumi.Input[_builtins.str]] = None,
            manifest: Optional[pulumi.Input[Union['AppsSettingsCustomTemplateManifestArgs', 'AppsSettingsCustomTemplateManifestArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            path: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['AppsSettingsCustomTemplateProviderConfigArgs', 'AppsSettingsCustomTemplateProviderConfigArgsDict']]] = None) -> 'AppsSettingsCustomTemplate':
        """
        Get an existing AppsSettingsCustomTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] creator: (string)
        :param pulumi.Input[_builtins.str] description: The description of the template
        :param pulumi.Input[_builtins.str] git_provider: The Git provider of the template
        :param pulumi.Input[_builtins.str] git_repo: The Git repository URL that the template resides in
        :param pulumi.Input[Union['AppsSettingsCustomTemplateManifestArgs', 'AppsSettingsCustomTemplateManifestArgsDict']] manifest: The manifest of the template. It defines fields and default values when installing the template
        :param pulumi.Input[_builtins.str] name: The name of the template. It must contain only alphanumeric characters, hyphens, underscores, and whitespaces.
               It must be unique within the workspace
        :param pulumi.Input[_builtins.str] path: The path to the template within the Git repository
        :param pulumi.Input[Union['AppsSettingsCustomTemplateProviderConfigArgs', 'AppsSettingsCustomTemplateProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppsSettingsCustomTemplateState.__new__(_AppsSettingsCustomTemplateState)

        __props__.__dict__["creator"] = creator
        __props__.__dict__["description"] = description
        __props__.__dict__["git_provider"] = git_provider
        __props__.__dict__["git_repo"] = git_repo
        __props__.__dict__["manifest"] = manifest
        __props__.__dict__["name"] = name
        __props__.__dict__["path"] = path
        __props__.__dict__["provider_config"] = provider_config
        return AppsSettingsCustomTemplate(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def creator(self) -> pulumi.Output[_builtins.str]:
        """
        (string)
        """
        return pulumi.get(self, "creator")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the template
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="gitProvider")
    def git_provider(self) -> pulumi.Output[_builtins.str]:
        """
        The Git provider of the template
        """
        return pulumi.get(self, "git_provider")

    @_builtins.property
    @pulumi.getter(name="gitRepo")
    def git_repo(self) -> pulumi.Output[_builtins.str]:
        """
        The Git repository URL that the template resides in
        """
        return pulumi.get(self, "git_repo")

    @_builtins.property
    @pulumi.getter
    def manifest(self) -> pulumi.Output['outputs.AppsSettingsCustomTemplateManifest']:
        """
        The manifest of the template. It defines fields and default values when installing the template
        """
        return pulumi.get(self, "manifest")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the template. It must contain only alphanumeric characters, hyphens, underscores, and whitespaces.
        It must be unique within the workspace
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Output[_builtins.str]:
        """
        The path to the template within the Git repository
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.AppsSettingsCustomTemplateProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetPostgresEndpointsResult',
    'AwaitableGetPostgresEndpointsResult',
    'get_postgres_endpoints',
    'get_postgres_endpoints_output',
]

@pulumi.output_type
class GetPostgresEndpointsResult:
    """
    A collection of values returned by getPostgresEndpoints.
    """
    def __init__(__self__, endpoints=None, id=None, page_size=None, parent=None, provider_config=None):
        if endpoints and not isinstance(endpoints, list):
            raise TypeError("Expected argument 'endpoints' to be a list")
        pulumi.set(__self__, "endpoints", endpoints)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if parent and not isinstance(parent, str):
            raise TypeError("Expected argument 'parent' to be a str")
        pulumi.set(__self__, "parent", parent)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter
    def endpoints(self) -> Sequence['outputs.GetPostgresEndpointsEndpointResult']:
        return pulumi.get(self, "endpoints")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "page_size")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> _builtins.str:
        """
        (string) - The branch containing this endpoint (API resource hierarchy).
        Format: projects/{project_id}/branches/{branch_id}
        """
        return pulumi.get(self, "parent")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetPostgresEndpointsProviderConfigResult']:
        return pulumi.get(self, "provider_config")


class AwaitableGetPostgresEndpointsResult(GetPostgresEndpointsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPostgresEndpointsResult(
            endpoints=self.endpoints,
            id=self.id,
            page_size=self.page_size,
            parent=self.parent,
            provider_config=self.provider_config)


def get_postgres_endpoints(page_size: Optional[_builtins.int] = None,
                           parent: Optional[_builtins.str] = None,
                           provider_config: Optional[Union['GetPostgresEndpointsProviderConfigArgs', 'GetPostgresEndpointsProviderConfigArgsDict']] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPostgresEndpointsResult:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source lists all Postgres endpoints in a branch.

    ## Example Usage

    ### List All Endpoints in a Branch

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_postgres_endpoints(parent="projects/my-project/branches/dev-branch")
    pulumi.export("endpointNames", [endpoint.name for endpoint in all.endpoints])
    pulumi.export("endpointTypes", [endpoint.status.endpoint_type for endpoint in all.endpoints])
    ```


    :param _builtins.int page_size: Upper bound for items returned. Cannot be negative
    :param _builtins.str parent: The Branch that owns this collection of endpoints.
           Format: projects/{project_id}/branches/{branch_id}
    :param Union['GetPostgresEndpointsProviderConfigArgs', 'GetPostgresEndpointsProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    __args__['parent'] = parent
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getPostgresEndpoints:getPostgresEndpoints', __args__, opts=opts, typ=GetPostgresEndpointsResult).value

    return AwaitableGetPostgresEndpointsResult(
        endpoints=pulumi.get(__ret__, 'endpoints'),
        id=pulumi.get(__ret__, 'id'),
        page_size=pulumi.get(__ret__, 'page_size'),
        parent=pulumi.get(__ret__, 'parent'),
        provider_config=pulumi.get(__ret__, 'provider_config'))
def get_postgres_endpoints_output(page_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                  parent: Optional[pulumi.Input[_builtins.str]] = None,
                                  provider_config: Optional[pulumi.Input[Optional[Union['GetPostgresEndpointsProviderConfigArgs', 'GetPostgresEndpointsProviderConfigArgsDict']]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPostgresEndpointsResult]:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source lists all Postgres endpoints in a branch.

    ## Example Usage

    ### List All Endpoints in a Branch

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_postgres_endpoints(parent="projects/my-project/branches/dev-branch")
    pulumi.export("endpointNames", [endpoint.name for endpoint in all.endpoints])
    pulumi.export("endpointTypes", [endpoint.status.endpoint_type for endpoint in all.endpoints])
    ```


    :param _builtins.int page_size: Upper bound for items returned. Cannot be negative
    :param _builtins.str parent: The Branch that owns this collection of endpoints.
           Format: projects/{project_id}/branches/{branch_id}
    :param Union['GetPostgresEndpointsProviderConfigArgs', 'GetPostgresEndpointsProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    __args__['parent'] = parent
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getPostgresEndpoints:getPostgresEndpoints', __args__, opts=opts, typ=GetPostgresEndpointsResult)
    return __ret__.apply(lambda __response__: GetPostgresEndpointsResult(
        endpoints=pulumi.get(__response__, 'endpoints'),
        id=pulumi.get(__response__, 'id'),
        page_size=pulumi.get(__response__, 'page_size'),
        parent=pulumi.get(__response__, 'parent'),
        provider_config=pulumi.get(__response__, 'provider_config')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WorkspaceEntityTagAssignmentArgs', 'WorkspaceEntityTagAssignment']

@pulumi.input_type
class WorkspaceEntityTagAssignmentArgs:
    def __init__(__self__, *,
                 entity_id: pulumi.Input[_builtins.str],
                 entity_type: pulumi.Input[_builtins.str],
                 tag_key: pulumi.Input[_builtins.str],
                 provider_config: Optional[pulumi.Input['WorkspaceEntityTagAssignmentProviderConfigArgs']] = None,
                 tag_value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a WorkspaceEntityTagAssignment resource.
        :param pulumi.Input[_builtins.str] entity_id: The identifier of the entity to which the tag is assigned. For apps, the entity_id is the app name
        :param pulumi.Input[_builtins.str] entity_type: The type of entity to which the tag is assigned. Allowed values are apps, dashboards, geniespaces, notebooks
        :param pulumi.Input[_builtins.str] tag_key: The key of the tag. The characters , . : / - = and leading/trailing spaces are not allowed
        :param pulumi.Input['WorkspaceEntityTagAssignmentProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] tag_value: The value of the tag
        """
        pulumi.set(__self__, "entity_id", entity_id)
        pulumi.set(__self__, "entity_type", entity_type)
        pulumi.set(__self__, "tag_key", tag_key)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if tag_value is not None:
            pulumi.set(__self__, "tag_value", tag_value)

    @_builtins.property
    @pulumi.getter(name="entityId")
    def entity_id(self) -> pulumi.Input[_builtins.str]:
        """
        The identifier of the entity to which the tag is assigned. For apps, the entity_id is the app name
        """
        return pulumi.get(self, "entity_id")

    @entity_id.setter
    def entity_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "entity_id", value)

    @_builtins.property
    @pulumi.getter(name="entityType")
    def entity_type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of entity to which the tag is assigned. Allowed values are apps, dashboards, geniespaces, notebooks
        """
        return pulumi.get(self, "entity_type")

    @entity_type.setter
    def entity_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "entity_type", value)

    @_builtins.property
    @pulumi.getter(name="tagKey")
    def tag_key(self) -> pulumi.Input[_builtins.str]:
        """
        The key of the tag. The characters , . : / - = and leading/trailing spaces are not allowed
        """
        return pulumi.get(self, "tag_key")

    @tag_key.setter
    def tag_key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "tag_key", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['WorkspaceEntityTagAssignmentProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['WorkspaceEntityTagAssignmentProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="tagValue")
    def tag_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of the tag
        """
        return pulumi.get(self, "tag_value")

    @tag_value.setter
    def tag_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tag_value", value)


@pulumi.input_type
class _WorkspaceEntityTagAssignmentState:
    def __init__(__self__, *,
                 entity_id: Optional[pulumi.Input[_builtins.str]] = None,
                 entity_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['WorkspaceEntityTagAssignmentProviderConfigArgs']] = None,
                 tag_key: Optional[pulumi.Input[_builtins.str]] = None,
                 tag_value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering WorkspaceEntityTagAssignment resources.
        :param pulumi.Input[_builtins.str] entity_id: The identifier of the entity to which the tag is assigned. For apps, the entity_id is the app name
        :param pulumi.Input[_builtins.str] entity_type: The type of entity to which the tag is assigned. Allowed values are apps, dashboards, geniespaces, notebooks
        :param pulumi.Input['WorkspaceEntityTagAssignmentProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] tag_key: The key of the tag. The characters , . : / - = and leading/trailing spaces are not allowed
        :param pulumi.Input[_builtins.str] tag_value: The value of the tag
        """
        if entity_id is not None:
            pulumi.set(__self__, "entity_id", entity_id)
        if entity_type is not None:
            pulumi.set(__self__, "entity_type", entity_type)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if tag_key is not None:
            pulumi.set(__self__, "tag_key", tag_key)
        if tag_value is not None:
            pulumi.set(__self__, "tag_value", tag_value)

    @_builtins.property
    @pulumi.getter(name="entityId")
    def entity_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier of the entity to which the tag is assigned. For apps, the entity_id is the app name
        """
        return pulumi.get(self, "entity_id")

    @entity_id.setter
    def entity_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "entity_id", value)

    @_builtins.property
    @pulumi.getter(name="entityType")
    def entity_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of entity to which the tag is assigned. Allowed values are apps, dashboards, geniespaces, notebooks
        """
        return pulumi.get(self, "entity_type")

    @entity_type.setter
    def entity_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "entity_type", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['WorkspaceEntityTagAssignmentProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['WorkspaceEntityTagAssignmentProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="tagKey")
    def tag_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The key of the tag. The characters , . : / - = and leading/trailing spaces are not allowed
        """
        return pulumi.get(self, "tag_key")

    @tag_key.setter
    def tag_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tag_key", value)

    @_builtins.property
    @pulumi.getter(name="tagValue")
    def tag_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of the tag
        """
        return pulumi.get(self, "tag_value")

    @tag_value.setter
    def tag_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tag_value", value)


@pulumi.type_token("databricks:index/workspaceEntityTagAssignment:WorkspaceEntityTagAssignment")
class WorkspaceEntityTagAssignment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 entity_id: Optional[pulumi.Input[_builtins.str]] = None,
                 entity_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['WorkspaceEntityTagAssignmentProviderConfigArgs', 'WorkspaceEntityTagAssignmentProviderConfigArgsDict']]] = None,
                 tag_key: Optional[pulumi.Input[_builtins.str]] = None,
                 tag_value: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        This resource allows you to create, update, list, and delete tag assignments for workspace scoped entities.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        notebook_tag = databricks.WorkspaceEntityTagAssignment("notebook_tag",
            entity_type="notebooks",
            entity_id="2807324866692453",
            tag_key="sensitivity_level",
            tag_value="high")
        app_tag = databricks.WorkspaceEntityTagAssignment("app_tag",
            entity_type="apps",
            entity_id="myapp",
            tag_key="sensitivity_level",
            tag_value="high")
        dashboard_tag = databricks.WorkspaceEntityTagAssignment("dashboard_tag",
            entity_type="dashboards",
            entity_id="2807324866692453",
            tag_key="sensitivity_level",
            tag_value="high")
        geniespace_tag = databricks.WorkspaceEntityTagAssignment("geniespace_tag",
            entity_type="geniespaces",
            entity_id="2807324866692453",
            tag_key="sensitivity_level",
            tag_value="high")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] entity_id: The identifier of the entity to which the tag is assigned. For apps, the entity_id is the app name
        :param pulumi.Input[_builtins.str] entity_type: The type of entity to which the tag is assigned. Allowed values are apps, dashboards, geniespaces, notebooks
        :param pulumi.Input[Union['WorkspaceEntityTagAssignmentProviderConfigArgs', 'WorkspaceEntityTagAssignmentProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] tag_key: The key of the tag. The characters , . : / - = and leading/trailing spaces are not allowed
        :param pulumi.Input[_builtins.str] tag_value: The value of the tag
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WorkspaceEntityTagAssignmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        This resource allows you to create, update, list, and delete tag assignments for workspace scoped entities.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        notebook_tag = databricks.WorkspaceEntityTagAssignment("notebook_tag",
            entity_type="notebooks",
            entity_id="2807324866692453",
            tag_key="sensitivity_level",
            tag_value="high")
        app_tag = databricks.WorkspaceEntityTagAssignment("app_tag",
            entity_type="apps",
            entity_id="myapp",
            tag_key="sensitivity_level",
            tag_value="high")
        dashboard_tag = databricks.WorkspaceEntityTagAssignment("dashboard_tag",
            entity_type="dashboards",
            entity_id="2807324866692453",
            tag_key="sensitivity_level",
            tag_value="high")
        geniespace_tag = databricks.WorkspaceEntityTagAssignment("geniespace_tag",
            entity_type="geniespaces",
            entity_id="2807324866692453",
            tag_key="sensitivity_level",
            tag_value="high")
        ```

        :param str resource_name: The name of the resource.
        :param WorkspaceEntityTagAssignmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkspaceEntityTagAssignmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 entity_id: Optional[pulumi.Input[_builtins.str]] = None,
                 entity_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['WorkspaceEntityTagAssignmentProviderConfigArgs', 'WorkspaceEntityTagAssignmentProviderConfigArgsDict']]] = None,
                 tag_key: Optional[pulumi.Input[_builtins.str]] = None,
                 tag_value: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkspaceEntityTagAssignmentArgs.__new__(WorkspaceEntityTagAssignmentArgs)

            if entity_id is None and not opts.urn:
                raise TypeError("Missing required property 'entity_id'")
            __props__.__dict__["entity_id"] = entity_id
            if entity_type is None and not opts.urn:
                raise TypeError("Missing required property 'entity_type'")
            __props__.__dict__["entity_type"] = entity_type
            __props__.__dict__["provider_config"] = provider_config
            if tag_key is None and not opts.urn:
                raise TypeError("Missing required property 'tag_key'")
            __props__.__dict__["tag_key"] = tag_key
            __props__.__dict__["tag_value"] = tag_value
        super(WorkspaceEntityTagAssignment, __self__).__init__(
            'databricks:index/workspaceEntityTagAssignment:WorkspaceEntityTagAssignment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            entity_id: Optional[pulumi.Input[_builtins.str]] = None,
            entity_type: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['WorkspaceEntityTagAssignmentProviderConfigArgs', 'WorkspaceEntityTagAssignmentProviderConfigArgsDict']]] = None,
            tag_key: Optional[pulumi.Input[_builtins.str]] = None,
            tag_value: Optional[pulumi.Input[_builtins.str]] = None) -> 'WorkspaceEntityTagAssignment':
        """
        Get an existing WorkspaceEntityTagAssignment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] entity_id: The identifier of the entity to which the tag is assigned. For apps, the entity_id is the app name
        :param pulumi.Input[_builtins.str] entity_type: The type of entity to which the tag is assigned. Allowed values are apps, dashboards, geniespaces, notebooks
        :param pulumi.Input[Union['WorkspaceEntityTagAssignmentProviderConfigArgs', 'WorkspaceEntityTagAssignmentProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] tag_key: The key of the tag. The characters , . : / - = and leading/trailing spaces are not allowed
        :param pulumi.Input[_builtins.str] tag_value: The value of the tag
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkspaceEntityTagAssignmentState.__new__(_WorkspaceEntityTagAssignmentState)

        __props__.__dict__["entity_id"] = entity_id
        __props__.__dict__["entity_type"] = entity_type
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["tag_key"] = tag_key
        __props__.__dict__["tag_value"] = tag_value
        return WorkspaceEntityTagAssignment(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="entityId")
    def entity_id(self) -> pulumi.Output[_builtins.str]:
        """
        The identifier of the entity to which the tag is assigned. For apps, the entity_id is the app name
        """
        return pulumi.get(self, "entity_id")

    @_builtins.property
    @pulumi.getter(name="entityType")
    def entity_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of entity to which the tag is assigned. Allowed values are apps, dashboards, geniespaces, notebooks
        """
        return pulumi.get(self, "entity_type")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.WorkspaceEntityTagAssignmentProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="tagKey")
    def tag_key(self) -> pulumi.Output[_builtins.str]:
        """
        The key of the tag. The characters , . : / - = and leading/trailing spaces are not allowed
        """
        return pulumi.get(self, "tag_key")

    @_builtins.property
    @pulumi.getter(name="tagValue")
    def tag_value(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The value of the tag
        """
        return pulumi.get(self, "tag_value")

